Enum ocl::async::Error
[−]
[src]
pub enum Error {
Ocl(OclError),
MpscSendError(String),
OneshotCanceled(OneshotCanceled),
Other(Box<Error>),
}An enum containing either a String or one of several other error types.
Implements the usual error traits.
Variants
Ocl(OclError)MpscSendError(String)OneshotCanceled(OneshotCanceled)Other(Box<Error>)Methods
impl Error[src]
fn string<S: Into<String>>(desc: S) -> Error
Returns a new Error::String with the given description.
fn prepend<'s, S: AsRef<&'s str>>(&'s mut self, txt: S)
If this is a String variant, concatenate txt to the front of the
contained string. Otherwise, do nothing at all.